==> haskell-ipynb-0.1.0.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ipynb
version:              0.1.0.1
visibility:           public
id:                   ipynb-0.1.0.1-Cvw6lPORRrCGveXj0V1aiM
key:                  ipynb-0.1.0.1-Cvw6lPORRrCGveXj0V1aiM
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  2ade204fe4821cbc1ac959bfc30a9f5c
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-8.10.1/site-local/ipynb-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/ipynb-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/ipynb-0.1.0.1
hs-libraries:         HSipynb-0.1.0.1-Cvw6lPORRrCGveXj0V1aiM
depends:
    aeson-1.4.7.1-ANEJrhOqgvGIzgMZodlboL base-4.14.0.0
    base64-bytestring-1.1.0.0-BUHOsOVhKeC5M6ZjmSxE5I
    bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.3.2
    unordered-containers-0.2.10.0-91W4S6Yfdzi8lLtBcprU0Q

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.1.0.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ipynb
version:              0.1.0.1
visibility:           public
id:                   ipynb-0.1.0.1-KQKUiRVdtaGICr485NyJDj
key:                  ipynb-0.1.0.1-KQKUiRVdtaGICr485NyJDj
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  48b7ffcee77d87033b75d4eb230a9d4d
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-8.10.1/site-local/ipynb-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/ipynb-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/ipynb-0.1.0.1
hs-libraries:         HSipynb-0.1.0.1-KQKUiRVdtaGICr485NyJDj
depends:
    aeson-1.5.1.0-9ZdAa5h0lJg1SCgI7etVaW base-4.14.0.0
    base64-bytestring-1.1.0.0-BUHOsOVhKeC5M6ZjmSxE5I
    bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.3.2
    unordered-containers-0.2.10.0-91W4S6Yfdzi8lLtBcprU0Q

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
